@@ -18,13 +18,13 @@ use Clone qw{ clone };
 use Hash::Merge qw{ merge };
 use List::Util qw{ max reduce };
 use Getopt::Long qw{
-    :config posix_default bundling require_order no_ignore_case
+    GetOptionsFromArray :config posix_default bundling require_order no_ignore_case
 };
 
 use Exporter 'import';
 our @EXPORT_OK = qw/startup/;
 
-our $VERSION = '0.27';    # Don't forget to update the manpage version, too!
+our $VERSION = '0.28';    # Don't forget to update the manpage version, too!
 
 use Readonly;
 Readonly my $V_FOR_VERBOSE => 'ALIAS OF VERBOSE';
@@ -712,7 +712,7 @@ sub _process_command_line
     my %options;
 
     # Parse the command line and die if anything is wrong.
-    my $opts_ok = GetOptions( \%options, keys %{$optspec} );
+    my $opts_ok = GetOptionsFromArray( \@ARGV, \%options, keys %{$optspec} );
 
     if ( $options{help} )
     {
@@ -1283,7 +1283,7 @@ CLI::Startup - Simple initialization for command-line scripts
 
 =head1 VERSION
 
-Version 0.27
+Version 0.28
 
 =head1 SYNOPSIS
 
